@@ -82,7 +82,7 @@ cfgfile_find_app_data_path (int *i_err)
 
     while ((s_p = strchr (s_sh, ':')) != NULL) {
         *s_p++ = '\0';
-        s_dir = str_comb (s_sh, PATH_APP_SHARE);
+        s_dir = str_comb (s_sh, PTH_SEP PTH_APP_SHORT);
         if ((*i_err = dir_check_permissions (s_dir)) == ERR_OK) {
             free (s_sh);
             return s_dir;
@@ -92,7 +92,7 @@ cfgfile_find_app_data_path (int *i_err)
         s_sh[ui_len] = '\0';
         free (s_dir);
     }
-    s_dir = str_comb (s_sh, PATH_APP_SHARE);
+    s_dir = str_comb (s_sh, PTH_SEP PTH_APP_SHORT);
     if ((*i_err = dir_check_permissions (s_dir)) == ERR_OK) {
         free (s_sh);
         return s_dir;
@@ -110,10 +110,11 @@ cfgfile_config_file_stuff (char **s_file,
                            int    i_create)
 {
     /* List of possible config paths in home directory */
-    const char *s_cfg_files[] = {"/wchanger/config.json",
-                                 "/wchanger.json",
-                                 "/wchanger/wchanger.json",
-                                 NULL};
+    const char *s_cfg_files[] = {
+        PTH_SEP PTH_APP_SHORT PTH_SEP PTH_CONFIG_FILE,
+        PTH_SEP PTH_OLDCFG_FILE,
+        PTH_SEP PTH_APP_SHORT PTH_SEP PTH_OLDCFG_FILE,
+        NULL};
     int i_res = 0; /* Function result */
 
     enum cfg_state {
@@ -190,12 +191,12 @@ cfgfile_config_file_stuff (char **s_file,
  * @brief  Get path for autostart desktop file for wchangerd daemon.
  */
 char *
-cfgfile_get_autostart_home_path (void)
+cfgfile_get_autostart_home_file_path (void)
 {
     char *s_path = NULL; /* Config file path */
 
-    s_path = dir_get_home_config ();
-    str_append (&s_path, PATH_AUTOSTART_HOME);
+    s_path = dir_get_autostart ();
+    str_append (&s_path, PTH_SEP PTH_ASTART_FILE_D);
 
     return s_path;
 }
@@ -204,12 +205,12 @@ cfgfile_get_autostart_home_path (void)
  * @brief  Get path for user's config file with window manager info.
  */
 char *
-cfgfile_get_wm_info_home_path (void)
+cfgfile_get_wm_info_home_file_path (void)
 {
     char *s_path = NULL; /* Config file path */
 
     s_path = dir_get_home_config ();
-    str_append (&s_path, PATH_WMINFO_HOME);
+    str_append (&s_path, PTH_SEP PTH_APP_SHORT PTH_SEP PTH_WMINFO_FILE);
 
     return s_path;
 }
@@ -218,7 +219,7 @@ cfgfile_get_wm_info_home_path (void)
  * @brief  Get path for default config file with window manager info.
  */
 char *
-cfgfile_get_wm_info_data_path (int *i_err)
+cfgfile_get_wm_info_data_file_path (int *i_err)
 {
     char *s_path = NULL; /* Config file path */
 
@@ -227,21 +228,21 @@ cfgfile_get_wm_info_data_path (int *i_err)
     if ((s_path = cfgfile_find_app_data_path (i_err)) == NULL)
         return NULL;
 
-    str_append (&s_path, PATH_WMINFO_DATA);
+    str_append (&s_path, PTH_SEP PTH_WMINFO_FILE);
 
     return s_path;
 }
 /*----------------------------------------------------------------------------*/
 /**
- * @brief  Get path for saving downloaded wallpapers
+ * @brief  Get directory path for downloaded wallpapers
  */
 char *
-cfgfile_get_app_wallpaper_path (void)
+cfgfile_get_app_wallpapers_path (void)
 {
     char *s_path = NULL; /* Config file path */
 
     s_path = dir_get_home_data ();
-    str_append (&s_path, PATH_WALLPAPERS);
+    str_append (&s_path, PTH_SEP PTH_APP_SHORT PTH_SEP PTH_WALLP_DIR);
 
     return s_path;
 }
@@ -255,7 +256,35 @@ cfgfile_get_app_cache_path (void)
     char *s_path = NULL; /* Config file path */
 
     s_path = dir_get_cache ();
-    str_append (&s_path, PATH_APP_CACHE);
+    str_append (&s_path, PTH_SEP PTH_APP_SHORT);
+
+    return s_path;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get directory path for thumbanils
+ */
+char *
+cfgfile_get_app_thumbnails_path (void)
+{
+    char *s_path = NULL; /* Config file path */
+
+    s_path = dir_get_cache ();
+    str_append (&s_path, PTH_SEP PTH_APP_SHORT PTH_SEP PTH_THUMB_DIR);
+
+    return s_path;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get directory with information about images.
+ */
+char *
+cfgfile_get_image_info_path (void)
+{
+    char *s_path = NULL; /* Config file path */
+
+    s_path = dir_get_cache ();
+    str_append (&s_path, PTH_SEP PTH_APP_SHORT PTH_SEP PTH_IINFO_DIR);
 
     return s_path;
 }
@@ -270,7 +299,7 @@ cfgfile_autostart_exists (void)
     char *s_path = NULL; /* Autostart file path */
     int  i_res   = 0;    /* File presence value to return */
 
-    s_path = cfgfile_get_autostart_home_path ();
+    s_path = cfgfile_get_autostart_home_file_path ();
 
     if (file_check_permissions (s_path) == ERR_OK) {
         i_res = 1;
@@ -294,9 +323,9 @@ cfgfile_autostart_create (void)
     if ((s_path = cfgfile_find_app_data_path (&i_err)) == NULL)
         return i_err;
 
-    s_as_path = cfgfile_get_autostart_home_path ();
+    s_as_path = cfgfile_get_autostart_home_file_path ();
 
-    str_append (&s_path, PATH_AUTOSTART_DATA);
+    str_append (&s_path, PTH_SEP PTH_ASTART_FILE_S);
 
     s_buff = read_file_data (s_path, &i_err);
     if (s_buff != NULL && i_err == ERR_OK) {
@@ -320,7 +349,7 @@ cfgfile_autostart_remove (void)
 {
     char *s_path = NULL; /* Autostart file path */
 
-    s_path = cfgfile_get_autostart_home_path ();
+    s_path = cfgfile_get_autostart_home_file_path ();
 
     if (remove (s_path) != 0) {
         warn ("%s", s_path);
