@@ -108,7 +108,7 @@ pexels_process_item_set_names (SearchItem *si_item)
 
     if (si_item->s_page_url == NULL)
         return;
-    if (si_item->s_image_url == NULL)
+    else if (si_item->s_image_url == NULL)
         return;
 
     /* Base name made of picture url */
@@ -148,6 +148,8 @@ pexels_json_obj_to_searchitem (json_object *j_obj)
 
     SearchItem *si_item = searchitem_new ();
 
+    searchitem_set_service_name (si_item, "Pexels");
+
     if (json_object_object_get_ex (j_obj, "id", &j_val) &&
         json_object_get_type (j_val) == json_type_int) {
 
@@ -268,6 +270,7 @@ pexels_json_to_webwidget (const char *s_buff,
                     add_searchitem_to_img_view (ww_widget->gw_img_view,
                                                 si_item,
                                                 ww_widget->s_thumb_dir,
+                                                ww_widget->s_wallp_dir,
                                                 "pexels_");
                     searchitem_free (si_item);
                 }
@@ -287,7 +290,7 @@ pexels_search (WebWidget         *ww_widget,
     UrlData *ud_data = NULL; /* For search results */
     char    *s_query = NULL; /* For search query */
 
-    if (check_is_empty (fs_data->s_str1, "Pexels API key is not set"))
+    if (str_is_empty_msg (fs_data->s_str1, "Pexels API key is not set"))
         return;
 
     s_query = str_replace_in (ww_widget->s_query, " ", "+");
