@@ -40,6 +40,7 @@
 #include "webpixbay.h"
 #include "webflickr.h"
 #include "webwidget.h"
+/*----------------------------------------------------------------------------*/
 /**
  * @def   NAME_LEN
  * @brief Lenght of name in download progress window.
@@ -49,7 +50,6 @@
  */
 #define NAME_LEN     40
 #define SEL_NAME_LEN 60
-
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Services combobox columns
@@ -127,7 +127,7 @@ download_progress_window (GtkWindow *gw_parent,
 
     /* Getting wallpaper save path and checking it's permissions, creating if
      * it doesn't exist */
-    s_wpdir = cfgfile_get_app_wallpaper_path ();
+    s_wpdir = cfgfile_get_app_wallpapers_path ();
     i_perm  = dir_check_permissions (s_wpdir);
 
     if (i_perm == ERR_FILE ||
@@ -443,10 +443,10 @@ event_search_pressed (WebWidget *ww_widget)
 
     if (!check_unicode (s_query, "Search query is not a valid unicode text"))
         return;
-    if (check_is_empty (s_query, "Empty search query"))
+    else if (str_is_empty_msg (s_query, "Empty search query"))
         return;
-    if (!check_is_alnum_space (s_query,
-                               "Sorry, only alphanumerich characters allowed"))
+    else if (!str_is_alnum_or_space (
+                s_query, "Sorry, only alphanumerich characters allowed"))
         return;
 
     if (ww_widget->s_query != NULL)
@@ -596,25 +596,25 @@ event_settings_pressed (WebWidget *ww_widget)
 static void
 event_add_selected_pressed (WebWidget *ww_widget)
 {
-    GtkListStore *gls_slstore;
-    GtkTreeModel *gtm_model;
-    GtkTreeModel *gtm_combo_model;
-    GdkPixbuf    *gp_pbuf;
-    GdkPixbuf    *gp_pbuf2;
-    GtkTreeIter   gti_iter;
-    GtkTreeIter   gti_iters;
-    GtkTreePath  *gtp_path;
-    GList        *gl_selected = NULL;
-    GList        *gl_item     = NULL;
-    char         *s_disp_name = NULL;
-    char         *s_file_name = NULL;
-    char         *s_image_url = NULL;
-    int           i_id        = 0;
-    int           i_w         = 0;
-    int           i_h         = 0;
-    float         f_w         = 0;
-    float         f_h         = 0;
-    char          s_dname[SEL_NAME_LEN * 4 + 4];
+    GtkListStore *gls_slstore;        /* Combobox ListStore */
+    GtkTreeModel *gtm_model;          /* Iconview tree model */
+    GtkTreeModel *gtm_combo_model;    /* Combobox tree model */
+    GdkPixbuf    *gp_pbuf;            /* Thumbnail pixbuf */
+    GdkPixbuf    *gp_pbuf2;           /* Smaller thumbnail pixbuf */
+    GtkTreeIter   gti_iter;           /* TreeIter */
+    GtkTreeIter   gti_iters;          /* TreeIter */
+    GtkTreePath  *gtp_path;           /* TreePath */
+    GList        *gl_selected = NULL; /* List of selected items */
+    GList        *gl_item     = NULL; /* List item for iteration */
+    char         *s_disp_name = NULL; /* Image display name */
+    char         *s_file_name = NULL; /* Image file name */
+    char         *s_image_url = NULL; /* Image url */
+    int           i_id        = 0;    /* Image id */
+    int           i_w         = 0;    /* Thumbnail width */
+    int           i_h         = 0;    /* Thumbnail height */
+    float         f_w         = 0;    /* Smaller thumbnail width */
+    float         f_h         = 0;    /* Smaller thumbnail height */
+    char          s_dname[SEL_NAME_LEN * 4 + 4]; /* For shorter name in combo */
 
     gtm_combo_model = gtk_combo_box_get_model (
             GTK_COMBO_BOX (ww_widget->gw_selected_combo));
@@ -1076,6 +1076,7 @@ webwidget_free (WebWidget *ww_widget)
     free (ww_widget->s_query);
     free (ww_widget->s_cfg_file);
     free (ww_widget->s_thumb_dir);
+    free (ww_widget->s_wallp_dir);
     free (ww_widget);
 }
 /*----------------------------------------------------------------------------*/
@@ -1106,8 +1107,8 @@ webwidget_create (Setting    *st_settings,
         err (EXIT_FAILURE, NULL);
 
     ww_widget->s_cfg_file  = strdup (s_cfg_file);
-    ww_widget->s_thumb_dir = cfgfile_get_app_cache_path ();
-    str_append (&ww_widget->s_thumb_dir, "/thumbnails");
+    ww_widget->s_thumb_dir = cfgfile_get_app_thumbnails_path ();
+    ww_widget->s_wallp_dir = cfgfile_get_app_wallpapers_path ();
     dir_create_with_subdirs (ww_widget->s_thumb_dir);
 
     ww_widget->gw_ii_widget = webwidget_imageinfo_create (ww_widget);
